@@ -160,3 +160,17 @@ class TestSourcesDefaultOrg(unittest.TestCase):
             self.assertTrue(True, "Dataset was created")
         except Exception as e:
             self.assertTrue(False, e)
+
+    def test_wait_for_pipeline(self):
+        """
+        Verify waitfor dataset endpoint with default org
+        :return:
+        """
+        try:
+            _ = self.sources.wait_for_dataset(
+                dataset_id=test_dataset["id"]
+            )
+
+            self.assertTrue(True, "Dataset became ready")
+        except Exception as e:
+            self.assertTrue(False, e)
