@@ -1207,6 +1207,7 @@ class Sources(ApiRequestManager):
     def update_dataset_metadata(self, org_id=None, *, dataset_id=None, name=None, description=None, facets=None):
         """
         Method to update a dataset's metadata
+
         :param org_id: org id where the pipeline is stored
         :param dataset_id: id of the pipeline to be edited
         :param name: new pipeline name
@@ -1215,16 +1216,26 @@ class Sources(ApiRequestManager):
         :return:
         """
 
-        query = self.gql_builder.mutation_query(
-            dataset_id=str(dataset_id),
-            new_name=name,
+        return self.update_artifact_metadata(
+            org_id=org_id,
+            artifact_id=dataset_id,
+            artifact_type="dataset",
+            name=name,
             description=description,
             facets=facets
         )
 
-        response = self.graph_ql_query(org_id=org_id, query=query)
+    @single_org
+    def wait_for_dataset(self, org_id=None, *, dataset_id):
+        """
+        Wait for a dataset to be ready to be used
 
-        if response.status_code in [200, 201, 202]:
-            return json.loads(response.content)
-
-        raise Exception(repr(response.content))
+        :param org_id: Organization id where the dataset was created
+        :param dataset_id: dataset id number
+        :return:
+        """
+        return self.wait_for_artifact(
+            org_id=org_id,
+            artifact_id=dataset_id,
+            artifact_type="dataset"
+        )
