@@ -23,6 +23,7 @@ from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
 from unify.generalutils import csv_to_json
 from unify.helpers.SingleOrg import single_org
+from unify.helpers.unify_objects.Template import Template as TemplateData
 
 
 class Templates(ApiRequestManager):
@@ -47,6 +48,10 @@ class Templates(ApiRequestManager):
 
             self.upload_content_type = 'text/tab-separated-values'
 
+            self.template_mng = "api/template_management/v1/orgs/{}"
+
+            self.org_uom_url = self.props.get_remote(self.cluster) + self.template_mng + "/uoms"
+
             self.template_list_url = "api/template_management/v1/orgs/{}/templates"
 
             self.delete_template_uri = 'api/template_management/v1/templates/{}'
@@ -511,3 +516,75 @@ class Templates(ApiRequestManager):
 
         except Exception as error:
             raise error
+
+    @single_org
+    def create_template_attribute_params(self, org_id=None, *, template_id, attribute_name, sanitized_name, data_type,
+                                         attribute_type,
+                                         description=None, uom=None, interpolation=None):
+        """
+        Creates a Custom template attribute
+
+        :param org_id: Org where the template exist
+        :param template_id: Template id where the new attribute will be added
+        :param attribute_name: Attribute full name
+        :param sanitized_name: Attribute Sanitized full name
+        :param data_type: Attribute Data type
+        :param attribute_type: Attribute type
+        :param description: Attribute description
+        :param uom: Attribute Unit Of Measure
+        :param interpolation: Attribute Interpolation Method
+        :return:
+        """
+
+        new_template = TemplateData()
+
+        for param, value in locals().items():
+            new_template.__setattr__(param, value)
+
+        return self.create_template_attribute(org_id=org_id, template=new_template)
+
+    @single_org
+    def create_template_attribute(self, org_id=None, *, template: TemplateData):
+        """
+        Creates a Custom template attribute
+
+        :param org_id:
+        :param template:
+        :return:
+        """
+
+        header = self.build_header(
+            org_id=org_id,
+            others=self.content_type_header
+        )
+
+        create_attribute = self.session.post(
+            self.template_attribute.format(org_id, template.template_id),
+            headers=header,
+            data=template.to_json()
+        )
+
+        if create_attribute.status_code in [200, 201]:
+            return json.loads(create_attribute.content)
+
+        raise Exception(json.loads(create_attribute.content))
+
+    @single_org
+    def get_uom(self, org_id=None):
+        """
+        Retrieve the list of unit of measure on the org
+
+        :param org_id: Organization id to be queried
+        :return:
+        """
+        header = self.build_header(
+            org_id=org_id,
+            others=self.content_type_header
+        )
+
+        get_response = self.session.get(self.org_uom_url.format(org_id), headers=header)
+
+        if get_response.status_code in [200]:
+            return json.loads(get_response.content)
+
+        raise Exception(json.loads(get_response.content))
